package VMOMI::DiagnosticPartitionType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
